==> shared_package_flutter-0.0.11.tar.gz: lib/components/showDialog/show_dialog.dart <==
library show_dialog;
import 'package:flutter/material.dart';

class FlatButtonParam{
  final String child;
  final Function onClickAction;

  FlatButtonParam( this.child, this.onClickAction );
}

class ShowDialogParam{
  final String title;
  final String content;
  final FlatButtonParam buttonAux;

  ShowDialogParam( this.title, this.content, { this.buttonAux } );
}

class ShowDialog{

  static Future<dynamic> show( BuildContext context, ShowDialogParam _parameter ){

    return showDialog(
      context: context,
      barrierDismissible: false,
      builder: ( context ){
        return AlertDialog(
          title: Text( _parameter.title ),
          content: Text( _parameter.content ),
          actions: <Widget>[
            (
              null != _parameter.buttonAux
              ? FlatButton(
                child: Text( _parameter.buttonAux.child ),
                onPressed: () {
                  _parameter.buttonAux.onClickAction( );
                  Navigator.pop( context );
                },
              )
              : null
            ),
            FlatButton(
              child: Text( "Fechar" ),
              onPressed: ( ) => Navigator.pop( context )
            )
          ],
        );
      }
    );
  }
}


// AlertDialog FilterDialog( Function closeFilter ){
//     final _formKey = GlobalKey<FormState>();

//     return AlertDialog(
//       content: Form(
//         key: _formKey,
//         child: Column(
//           mainAxisSize: MainAxisSize.min,
//           children: <Widget>[
//             Padding(
//               padding: EdgeInsets.all(8.0),
//               child: TextFormField(),
//             ),
//             Padding(
//               padding: EdgeInsets.all(8.0),
//               child: TextFormField(),
//             ),
//             Padding(
//               padding: const EdgeInsets.all(8.0),
//               child: Row(
//                 children: <Widget>[
//                   RaisedButton(
//                     child: Text("Submitß"),
//                     onPressed: () {
//                       if (_formKey.currentState.validate()) {
//                         _formKey.currentState.save();
//                       }
//                     },
//                   ),
//                   Padding( padding: EdgeInsets.only( left: 25.0 ) ),
//                   RaisedButton(
//                     child: Text("Fechar"),
//                     onPressed: () {
//                       closeFilter();
//                     },
//                   )
//                 ],
//               ),
//             )
//           ],
//         ),
//       )
//     );
//   }

==> shared_package_flutter-0.0.15.tar.gz: lib/components/showDialog/show_dialog.dart <==
library show_dialog;
import 'package:flutter/material.dart';

class FlatButtonParam{
  final String child;
  final Function onClickAction;

  FlatButtonParam( this.child, this.onClickAction );
}

class ShowDialogParam{
  final String title;
  final String content;
  final FlatButtonParam buttonSecondary;

  ShowDialogParam( this.title, this.content, { this.buttonSecondary } );
}

class ShowDialog{

  static Future<dynamic> show( BuildContext context, ShowDialogParam _parameter ){

    return showDialog(
      context: context,
      barrierDismissible: false,
      builder: ( context ){
        return AlertDialog(
          title: Text( _parameter.title ),
          content: Text( _parameter.content ),
          actions: <Widget>[
            (
              null != _parameter.buttonSecondary
              ? FlatButton(
                child: Text( _parameter.buttonSecondary.child ),
                onPressed: () {
                  _parameter.buttonSecondary.onClickAction( );
                  Navigator.pop( context );
                },
              )
              : null
            ),
            FlatButton(
              child: Text( "Fechar" ),
              onPressed: ( ) => Navigator.pop( context )
            )
          ],
        );
      }
    );
  }
}


// AlertDialog FilterDialog( Function closeFilter ){
//     final _formKey = GlobalKey<FormState>();

//     return AlertDialog(
//       content: Form(
//         key: _formKey,
//         child: Column(
//           mainAxisSize: MainAxisSize.min,
//           children: <Widget>[
//             Padding(
//               padding: EdgeInsets.all(8.0),
//               child: TextFormField(),
//             ),
//             Padding(
//               padding: EdgeInsets.all(8.0),
//               child: TextFormField(),
//             ),
//             Padding(
//               padding: const EdgeInsets.all(8.0),
//               child: Row(
//                 children: <Widget>[
//                   RaisedButton(
//                     child: Text("Submitß"),
//                     onPressed: () {
//                       if (_formKey.currentState.validate()) {
//                         _formKey.currentState.save();
//                       }
//                     },
//                   ),
//                   Padding( padding: EdgeInsets.only( left: 25.0 ) ),
//                   RaisedButton(
//                     child: Text("Fechar"),
//                     onPressed: () {
//                       closeFilter();
//                     },
//                   )
//                 ],
//               ),
//             )
//           ],
//         ),
//       )
//     );
//   }
